TEXT = {
    "locked.function": "似乎这个函数已经被锁定了，通过关卡解锁吧。",
    "locked.class": "似乎这个类型已经被锁定了，通过关卡解锁吧。",

    "answer.fit": "恭喜，输出符合预期 ",
    "answer.unfit": "啊哦，似乎哪里出了问题。。。",
    "answer.expected": "预期结果：",
    "answer.actual": "你的结果："
}
