BIF = [
    'abs', 'all', 'any', 'bin',
    'callable', 'chr', 'compile',
    'dir', 'divmod',
    'eval', 'exec', 'exit', 'format',
    'frozenset', 'hash', 'hex', 'input',
    'isinstance', 'issubclass', 'iter',
    'len',  'max', 'min', 'next',
    'oct', 'open', 'ord', 'pow', 'print',
    'quit', 'repr', 'globals', 'locals',
    'round', 'sorted', 'sum',
    'vars']

BIT = [
    'bool', 'bytearray', 'bytes',
    'complex', 'dict', 'enumerate',
    'filter', 'float', 'int', 'list',
    'map', 'object', 'range',
    'staticmethod', 'classmethod', 'property',
    'reversed', 'set', 'slice', 'str', 'super',
    'tuple', 'type', 'zip'
]